Add rcu_read_ongoing() API to each urcu flavor
[urcu.git] / urcu.h
diff --git a/urcu.h b/urcu.h
index 69c06e409ddaf2bb95d96d27ae6d9369b777d40b..b8ca700ddcdb750270c5e39bd86080b559102363 100644 (file)
--- a/urcu.h
+++ b/urcu.h
@@ -6,7 +6,7 @@
  *
  * Userspace RCU header
  *
- * Copyright (c) 2009 Mathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
+ * Copyright (c) 2009 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
  * Copyright (c) 2009 Paul E. McKenney, IBM Corporation.
  *
  * LGPL-compatible code should include this header with :
 #include <pthread.h>
 
 /*
- * See urcu-pointer.h and urcu-pointer-static.h for pointer publication headers.
+ * See urcu-pointer.h and urcu/static/urcu-pointer.h for pointer
+ * publication headers.
  */
 #include <urcu-pointer.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif 
+
+#include <urcu/map/urcu.h>
+
 /*
  * Important !
  *
  * Each thread containing read-side critical sections must be registered
- * with rcu_register_thread() before calling rcu_read_lock().
- * rcu_unregister_thread() should be called before the thread exits.
+ * with rcu_register_thread_mb() before calling rcu_read_lock_mb().
+ * rcu_unregister_thread_mb() should be called before the thread exits.
  */
 
 #ifdef _LGPL_SOURCE
 
-#include <urcu-static.h>
+#include <urcu/static/urcu.h>
 
 /*
  * Mappings for static use of the userspace RCU library.
  * DON'T FORGET TO USE RCU_REGISTER/UNREGISTER_THREAD() FOR EACH THREAD WITH
  * READ-SIDE CRITICAL SECTION.
  */
-#define rcu_read_lock()                _rcu_read_lock()
-#define rcu_read_unlock()      _rcu_read_unlock()
+#ifdef RCU_MEMBARRIER
+#define rcu_read_lock_memb             _rcu_read_lock
+#define rcu_read_unlock_memb           _rcu_read_unlock
+#define rcu_read_ongoing_memb          _rcu_read_ongoing
+#elif defined(RCU_SIGNAL)
+#define rcu_read_lock_sig              _rcu_read_lock
+#define rcu_read_unlock_sig            _rcu_read_unlock
+#define rcu_read_ongoing_sig           _rcu_read_ongoing
+#elif defined(RCU_MB)
+#define rcu_read_lock_mb               _rcu_read_lock
+#define rcu_read_unlock_mb             _rcu_read_unlock
+#define rcu_read_ongoing_mb            _rcu_read_ongoing
+#endif
 
 #else /* !_LGPL_SOURCE */
 
 /*
  * library wrappers to be used by non-LGPL compatible source code.
- * See LGPL-only urcu-pointer-static.h for documentation.
+ * See LGPL-only urcu/static/urcu-pointer.h for documentation.
  */
 
 extern void rcu_read_lock(void);
 extern void rcu_read_unlock(void);
+extern int rcu_read_ongoing(void);
 
 #endif /* !_LGPL_SOURCE */
 
@@ -88,8 +107,31 @@ extern void rcu_register_thread(void);
 extern void rcu_unregister_thread(void);
 
 /*
- * Explicit urcu initialization, for "early" use within library constructors.
+ * Explicit rcu initialization, for "early" use within library constructors.
+ */
+extern void rcu_init(void);
+
+/*
+ * Q.S. reporting are no-ops for these URCU flavors.
  */
-extern void urcu_init(void);
+static inline void rcu_quiescent_state(void)
+{
+}
+
+static inline void rcu_thread_offline(void)
+{
+}
+
+static inline void rcu_thread_online(void)
+{
+}
+
+#ifdef __cplusplus 
+}
+#endif
+
+#include <urcu-call-rcu.h>
+#include <urcu-defer.h>
+#include <urcu-flavor.h>
 
 #endif /* _URCU_H */
This page took 0.023486 seconds and 4 git commands to generate.